diff --git a/spring-aspects/src/main/java/org/springframework/context/annotation/aspectj/SpringConfiguredConfiguration.java b/spring-aspects/src/main/java/org/springframework/context/annotation/aspectj/SpringConfiguredConfiguration.java
index 8534fd76b5..747f280f27 100644
--- a/spring-aspects/src/main/java/org/springframework/context/annotation/aspectj/SpringConfiguredConfiguration.java
+++ b/spring-aspects/src/main/java/org/springframework/context/annotation/aspectj/SpringConfiguredConfiguration.java
@@ -1,5 +1,5 @@
/*
- * Copyright 2002-2012 the original author or authors.
+ * Copyright 2002-2015 the original author or authors.
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
@@ -28,9 +28,9 @@ import org.springframework.context.annotation.Role;
* annotated with @{@link org.springframework.beans.factory.annotation.Configurable
* Configurable}.
*
- *
This configuration class is automatically imported when using the @{@link
- * EnableSpringConfigured} annotation. See {@code @EnableSpringConfigured} Javadoc for
- * complete usage details.
+ *
This configuration class is automatically imported when using the
+ * @{@link EnableSpringConfigured} annotation. See {@code @EnableSpringConfigured}'s
+ * javadoc for complete usage details.
*
* @author Chris Beams
* @since 3.1
@@ -42,9 +42,10 @@ public class SpringConfiguredConfiguration {
public static final String BEAN_CONFIGURER_ASPECT_BEAN_NAME =
"org.springframework.context.config.internalBeanConfigurerAspect";
- @Bean(name=BEAN_CONFIGURER_ASPECT_BEAN_NAME)
+ @Bean(name = BEAN_CONFIGURER_ASPECT_BEAN_NAME)
@Role(BeanDefinition.ROLE_INFRASTRUCTURE)
public AnnotationBeanConfigurerAspect beanConfigurerAspect() {
return AnnotationBeanConfigurerAspect.aspectOf();
}
+
}
diff --git a/spring-context/src/main/java/org/springframework/context/annotation/LoadTimeWeavingConfiguration.java b/spring-context/src/main/java/org/springframework/context/annotation/LoadTimeWeavingConfiguration.java
index 6b4ab8dd41..c52dad401d 100644
--- a/spring-context/src/main/java/org/springframework/context/annotation/LoadTimeWeavingConfiguration.java
+++ b/spring-context/src/main/java/org/springframework/context/annotation/LoadTimeWeavingConfiguration.java
@@ -1,5 +1,5 @@
/*
- * Copyright 2002-2013 the original author or authors.
+ * Copyright 2002-2015 the original author or authors.
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
@@ -47,7 +47,7 @@ public class LoadTimeWeavingConfiguration implements ImportAware, BeanClassLoade
private AnnotationAttributes enableLTW;
- @Autowired(required=false)
+ @Autowired(required = false)
private LoadTimeWeavingConfigurer ltwConfigurer;
private ClassLoader beanClassLoader;
@@ -66,7 +66,7 @@ public class LoadTimeWeavingConfiguration implements ImportAware, BeanClassLoade
}
- @Bean(name=ConfigurableApplicationContext.LOAD_TIME_WEAVER_BEAN_NAME)
+ @Bean(name = ConfigurableApplicationContext.LOAD_TIME_WEAVER_BEAN_NAME)
@Role(BeanDefinition.ROLE_INFRASTRUCTURE)
public LoadTimeWeaver loadTimeWeaver() {
LoadTimeWeaver loadTimeWeaver = null;
diff --git a/spring-context/src/main/java/org/springframework/scheduling/annotation/AbstractAsyncConfiguration.java b/spring-context/src/main/java/org/springframework/scheduling/annotation/AbstractAsyncConfiguration.java
index 78cf5691fa..e13320921e 100644
--- a/spring-context/src/main/java/org/springframework/scheduling/annotation/AbstractAsyncConfiguration.java
+++ b/spring-context/src/main/java/org/springframework/scheduling/annotation/AbstractAsyncConfiguration.java
@@ -1,5 +1,5 @@
/*
- * Copyright 2002-2014 the original author or authors.
+ * Copyright 2002-2015 the original author or authors.
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
@@ -43,6 +43,7 @@ public abstract class AbstractAsyncConfiguration implements ImportAware {
protected AnnotationAttributes enableAsync;
protected Executor executor;
+
protected AsyncUncaughtExceptionHandler exceptionHandler;
@@ -57,7 +58,7 @@ public abstract class AbstractAsyncConfiguration implements ImportAware {
/**
* Collect any {@link AsyncConfigurer} beans through autowiring.
*/
- @Autowired(required=false)
+ @Autowired(required = false)
void setConfigurers(Collection configurers) {
if (CollectionUtils.isEmpty(configurers)) {
return;
diff --git a/spring-tx/src/main/java/org/springframework/transaction/annotation/ProxyTransactionManagementConfiguration.java b/spring-tx/src/main/java/org/springframework/transaction/annotation/ProxyTransactionManagementConfiguration.java
index 40a8637345..616551c67b 100644
--- a/spring-tx/src/main/java/org/springframework/transaction/annotation/ProxyTransactionManagementConfiguration.java
+++ b/spring-tx/src/main/java/org/springframework/transaction/annotation/ProxyTransactionManagementConfiguration.java
@@ -1,5 +1,5 @@
/*
- * Copyright 2002-2013 the original author or authors.
+ * Copyright 2002-2015 the original author or authors.
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
@@ -26,8 +26,8 @@ import org.springframework.transaction.interceptor.TransactionAttributeSource;
import org.springframework.transaction.interceptor.TransactionInterceptor;
/**
- * {@code @Configuration} class that registers the Spring infrastructure beans necessary
- * to enable proxy-based annotation-driven transaction management.
+ * {@code @Configuration} class that registers the Spring infrastructure beans
+ * necessary to enable proxy-based annotation-driven transaction management.
*
* @author Chris Beams
* @since 3.1
@@ -37,7 +37,7 @@ import org.springframework.transaction.interceptor.TransactionInterceptor;
@Configuration
public class ProxyTransactionManagementConfiguration extends AbstractTransactionManagementConfiguration {
- @Bean(name=TransactionManagementConfigUtils.TRANSACTION_ADVISOR_BEAN_NAME)
+ @Bean(name = TransactionManagementConfigUtils.TRANSACTION_ADVISOR_BEAN_NAME)
@Role(BeanDefinition.ROLE_INFRASTRUCTURE)
public BeanFactoryTransactionAttributeSourceAdvisor transactionAdvisor() {
BeanFactoryTransactionAttributeSourceAdvisor advisor = new BeanFactoryTransactionAttributeSourceAdvisor();
diff --git a/spring-websocket/src/main/java/org/springframework/web/socket/config/annotation/DelegatingWebSocketMessageBrokerConfiguration.java b/spring-websocket/src/main/java/org/springframework/web/socket/config/annotation/DelegatingWebSocketMessageBrokerConfiguration.java
index 8edcccc95c..d11637aad6 100644
--- a/spring-websocket/src/main/java/org/springframework/web/socket/config/annotation/DelegatingWebSocketMessageBrokerConfiguration.java
+++ b/spring-websocket/src/main/java/org/springframework/web/socket/config/annotation/DelegatingWebSocketMessageBrokerConfiguration.java
@@ -1,5 +1,5 @@
/*
- * Copyright 2002-2013 the original author or authors.
+ * Copyright 2002-2015 the original author or authors.
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
@@ -29,10 +29,10 @@ import org.springframework.messaging.simp.config.MessageBrokerRegistry;
import org.springframework.util.CollectionUtils;
/**
- * A {@link WebSocketMessageBrokerConfigurationSupport} extension that detects beans of type
- * {@link WebSocketMessageBrokerConfigurer}
- * and delegates to all of them allowing callback style customization of the
- * configuration provided in {@link WebSocketMessageBrokerConfigurationSupport}.
+ * A {@link WebSocketMessageBrokerConfigurationSupport} extension that detects
+ * beans of type {@link WebSocketMessageBrokerConfigurer} and delegates to all
+ * of them allowing callback style customization of the configuration provided
+ * in {@link WebSocketMessageBrokerConfigurationSupport}.
*
* This class is typically imported via {@link EnableWebSocketMessageBroker}.
*
@@ -42,10 +42,10 @@ import org.springframework.util.CollectionUtils;
@Configuration
public class DelegatingWebSocketMessageBrokerConfiguration extends WebSocketMessageBrokerConfigurationSupport {
- private List configurers = new ArrayList();
+ private final List configurers = new ArrayList();
- @Autowired(required=false)
+ @Autowired(required = false)
public void setConfigurers(List configurers) {
if (!CollectionUtils.isEmpty(configurers)) {
this.configurers.addAll(configurers);
@@ -55,51 +55,51 @@ public class DelegatingWebSocketMessageBrokerConfiguration extends WebSocketMess
@Override
protected void registerStompEndpoints(StompEndpointRegistry registry) {
- for (WebSocketMessageBrokerConfigurer c : this.configurers) {
- c.registerStompEndpoints(registry);
+ for (WebSocketMessageBrokerConfigurer configurer : this.configurers) {
+ configurer.registerStompEndpoints(registry);
}
}
@Override
protected void configureWebSocketTransport(WebSocketTransportRegistration registration) {
- for (WebSocketMessageBrokerConfigurer c : this.configurers) {
- c.configureWebSocketTransport(registration);
+ for (WebSocketMessageBrokerConfigurer configurer : this.configurers) {
+ configurer.configureWebSocketTransport(registration);
}
}
@Override
protected void configureClientInboundChannel(ChannelRegistration registration) {
- for (WebSocketMessageBrokerConfigurer c : this.configurers) {
- c.configureClientInboundChannel(registration);
+ for (WebSocketMessageBrokerConfigurer configurer : this.configurers) {
+ configurer.configureClientInboundChannel(registration);
}
}
@Override
protected void configureClientOutboundChannel(ChannelRegistration registration) {
- for (WebSocketMessageBrokerConfigurer c : this.configurers) {
- c.configureClientOutboundChannel(registration);
+ for (WebSocketMessageBrokerConfigurer configurer : this.configurers) {
+ configurer.configureClientOutboundChannel(registration);
}
}
@Override
protected void addArgumentResolvers(List argumentResolvers) {
- for (WebSocketMessageBrokerConfigurer c : this.configurers) {
- c.addArgumentResolvers(argumentResolvers);
+ for (WebSocketMessageBrokerConfigurer configurer : this.configurers) {
+ configurer.addArgumentResolvers(argumentResolvers);
}
}
@Override
protected void addReturnValueHandlers(List returnValueHandlers) {
- for (WebSocketMessageBrokerConfigurer c : this.configurers) {
- c.addReturnValueHandlers(returnValueHandlers);
+ for (WebSocketMessageBrokerConfigurer configurer : this.configurers) {
+ configurer.addReturnValueHandlers(returnValueHandlers);
}
}
@Override
protected boolean configureMessageConverters(List messageConverters) {
boolean registerDefaults = true;
- for (WebSocketMessageBrokerConfigurer c : this.configurers) {
- if (!c.configureMessageConverters(messageConverters)) {
+ for (WebSocketMessageBrokerConfigurer configurer : this.configurers) {
+ if (!configurer.configureMessageConverters(messageConverters)) {
registerDefaults = false;
}
}
@@ -108,8 +108,8 @@ public class DelegatingWebSocketMessageBrokerConfiguration extends WebSocketMess
@Override
protected void configureMessageBroker(MessageBrokerRegistry registry) {
- for (WebSocketMessageBrokerConfigurer c : this.configurers) {
- c.configureMessageBroker(registry);
+ for (WebSocketMessageBrokerConfigurer configurer : this.configurers) {
+ configurer.configureMessageBroker(registry);
}
}
diff --git a/spring-jdbc/src/main/java/org/springframework/jdbc/datasource/init/ScriptStatementFailedException.java b/spring-jdbc/src/main/java/org/springframework/jdbc/datasource/init/ScriptStatementFailedException.java
index 0bb59c5efd..47e922e87d 100644
--- a/spring-jdbc/src/main/java/org/springframework/jdbc/datasource/init/ScriptStatementFailedException.java
+++ b/spring-jdbc/src/main/java/org/springframework/jdbc/datasource/init/ScriptStatementFailedException.java
@@ -31,15 +31,14 @@ public class ScriptStatementFailedException extends ScriptException {
/**
* Construct a new {@code ScriptStatementFailedException}.
* @param statement the actual SQL statement that failed
* @param statementNumber the statement number in the SQL script (i.e.,
* the nth statement present in the resource)
* @param resource the resource from which the SQL statement was read
* @param cause the underlying cause of the failure
*/
- public ScriptStatementFailedException(String statement, int statementNumber, EncodedResource resource, Throwable cause) {
- super("Failed to execute SQL script statement #" + statementNumber + " of resource " + resource + ": "
- + statement, cause);
+ public ScriptStatementFailedException(String stmt, int stmtNumber, EncodedResource resource, Throwable cause) {
+ super("Failed to execute SQL script statement #" + stmtNumber + " of resource " + resource + ": " + stmt, cause);
}
}
@@ -31,15 +31,14 @@ public class ScriptStatementFailedException extends ScriptException {
/**
* Construct a new {@code ScriptStatementFailedException}.
- * @param statement the actual SQL statement that failed
- * @param statementNumber the statement number in the SQL script (i.e.,
+ * @param stmt the actual SQL statement that failed
+ * @param stmtNumber the statement number in the SQL script (i.e.,
* the nth statement present in the resource)
* @param resource the resource from which the SQL statement was read